==> nextcloud-24.0.5.tgz: nextcloud/apps/viewer/l10n/de_DE.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Vorschau Ihrer favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Ihr Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "Unsaved changes" : "Ungespeicherte Änderungen",
    "Drop changes" : "Änderungen verwerfen",
    "Your browser does not support videos." : "Ihr Browser unterstützt keine Videos.",
    "Edit" : "Bearbeiten",
    "Open sidebar" : "Seitenleiste öffnen",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "View" : "Ansicht",
    "Name" : "Name",
    "Save" : "Speichern",
    "Save as" : "Speichern als",
    "Back" : "Zurück",
    "Loading …" : "Lade …",
    "Reset" : "Zurücksetzen",
    "All changes will be lost." : "Alle Änderungen gehen verloren.",
    "Are you sure you want to continue?" : "Sind Sie sich sicher, dass Sie fortsetzen wollen?",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "Undo" : "Rückgängig",
    "Redo" : "Wiederherstellen",
    "Show original image" : "Originalbild anzeigen",
    "Zoom in" : "Hineinzoomen",
    "Zoom out" : "Hinauszoomen",
    "Toggle zoom menu" : "Zoom-Menü umschalten",
    "Adjust" : "Anpassen",
    "Fine-tune" : "Feinabstimmung",
    "Filters" : "Filter",
    "Watermark" : "Wasserzeichen",
    "Draw" : "Zeichnen",
    "Resize" : "Größe ändern",
    "Invalid image." : "Ungültiges Bild.",
    "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
    "are not images" : "Sind keine Bilder",
    "is not an image" : "Ist kein Bild",
    "to be uploaded" : "zum Hochladen",
    "Crop" : "Zuschneiden",
    "Original" : "Original",
    "Custom" : "Benutzerdefiniert",
    "Square" : "Quadrat",
    "Landscape" : "Landschaft",
    "Portrait" : "Porträt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klassisches Fernsehen",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pfeil",
    "Blur" : "Verwischen",
    "Brightness" : "Helligkeit",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Spiegeln X rückgängig",
    "Flip X" : "Spiegeln X",
    "Un-flip Y" : "Spiegeln Y rückgängig",
    "Flip Y" : "Spiegeln Y",
    "HSV" : "HSV",
    "Hue" : "Farbton",
    "Saturation" : "Sättigung",
    "Value" : "Wert",
    "Image" : "Bild",
    "Importing …" : "Importiere…",
    "+ Add image" : "+ Bild hinzufügen",
    "Line" : "Linie",
    "Pen" : "Stift",
    "Polygon" : "Polygon",
    "Sides" : "Seiten",
    "Rectangle" : "Rechteck",
    "Corner Radius" : "Eckenradius",
    "Width in pixels" : "Breite in Pixel",
    "Height in pixels" : "Höhe in Pixel",
    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
    "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
    "Rotate" : "Rotieren",
    "Text" : "Text",
    "Text spacing" : "Text-Abstand",
    "Text alignment" : "Textausrichtung",
    "Font family" : "Schriftenfamilie",
    "Size" : "Größe",
    "Letter spacing" : "Buchstaben-Abstand",
    "Line height" : "Zeilenhöhe",
    "Warmth" : "Wärme",
    "+ Add watermark" : "+ Wasserzeichen hinzufügen",
    "Choose watermark type" : "Wasserzeichentyp auswählen",
    "Upload watermark" : "Wasserzeichen hochladen",
    "Add as text" : "Als Text hinzufügen",
    "Padding" : "Auffüllen",
    "Shadow" : "Schatten",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Deckkraft",
    "Position" : "Position",
    "Stroke" : " Strich",
    "Save image as" : "Bild speichern als",
    "Extension" : "Erweiterung",
    "Name is required." : "Name ist erforderlich.",
    "Quality" : "Qualität",
    "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachten Sie, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann",
    "Actual size (100%)" : "Tatsächliche Größe (100%)",
    "Fit size" : "Größe anpassen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/viewer/l10n/de_DE.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Vorschau Ihrer favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Ihr Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "Image saved" : "Bild gespeichert",
    "Error saving image" : "Fehler beim Speichern des Bildes",
    "Unsaved changes" : "Ungespeicherte Änderungen",
    "Drop changes" : "Änderungen verwerfen",
    "Content of \"{fileName}\"" : "Inhalt von \"{fileName}\"",
    "Your browser does not support videos." : "Ihr Browser unterstützt keine Videos.",
    "Edit" : "Bearbeiten",
    "Open sidebar" : "Seitenleiste öffnen",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "View" : "Ansicht",
    "Name" : "Name",
    "Save" : "Speichern",
    "Save as" : "Speichern als",
    "Back" : "Zurück",
    "Loading …" : "Lade …",
    "Reset" : "Zurücksetzen",
    "All changes will be lost." : "Alle Änderungen gehen verloren.",
    "Are you sure you want to continue?" : "Sind Sie sich sicher, dass Sie fortsetzen wollen?",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "Undo" : "Rückgängig",
    "Redo" : "Wiederherstellen",
    "Show original image" : "Originalbild anzeigen",
    "Zoom in" : "Hineinzoomen",
    "Zoom out" : "Hinauszoomen",
    "Toggle zoom menu" : "Zoom-Menü umschalten",
    "Adjust" : "Anpassen",
    "Fine-tune" : "Feinabstimmung",
    "Filters" : "Filter",
    "Watermark" : "Wasserzeichen",
    "Draw" : "Zeichnen",
    "Resize" : "Größe ändern",
    "Invalid image." : "Ungültiges Bild.",
    "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
    "are not images" : "Sind keine Bilder",
    "is not an image" : "Ist kein Bild",
    "to be uploaded" : "zum Hochladen",
    "Crop" : "Zuschneiden",
    "Original" : "Original",
    "Custom" : "Benutzerdefiniert",
    "Square" : "Quadrat",
    "Landscape" : "Landschaft",
    "Portrait" : "Porträt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klassisches Fernsehen",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pfeil",
    "Blur" : "Verwischen",
    "Brightness" : "Helligkeit",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Spiegeln X rückgängig",
    "Flip X" : "Spiegeln X",
    "Un-flip Y" : "Spiegeln Y rückgängig",
    "Flip Y" : "Spiegeln Y",
    "HSV" : "HSV",
    "Hue" : "Farbton",
    "Saturation" : "Sättigung",
    "Value" : "Wert",
    "Image" : "Bild",
    "Importing …" : "Importiere…",
    "+ Add image" : "+ Bild hinzufügen",
    "Line" : "Linie",
    "Pen" : "Stift",
    "Polygon" : "Polygon",
    "Sides" : "Seiten",
    "Rectangle" : "Rechteck",
    "Corner Radius" : "Eckenradius",
    "Width in pixels" : "Breite in Pixel",
    "Height in pixels" : "Höhe in Pixel",
    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
    "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
    "Rotate" : "Rotieren",
    "Text" : "Text",
    "Text spacing" : "Text-Abstand",
    "Text alignment" : "Textausrichtung",
    "Font family" : "Schriftenfamilie",
    "Size" : "Größe",
    "Letter spacing" : "Buchstaben-Abstand",
    "Line height" : "Zeilenhöhe",
    "Warmth" : "Wärme",
    "+ Add watermark" : "+ Wasserzeichen hinzufügen",
    "Choose watermark type" : "Wasserzeichentyp auswählen",
    "Upload watermark" : "Wasserzeichen hochladen",
    "Add as text" : "Als Text hinzufügen",
    "Padding" : "Auffüllen",
    "Shadow" : "Schatten",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Deckkraft",
    "Position" : "Position",
    "Stroke" : " Strich",
    "Save image as" : "Bild speichern als",
    "Extension" : "Erweiterung",
    "Name is required." : "Name ist erforderlich.",
    "Quality" : "Qualität",
    "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachten Sie, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann",
    "Actual size (100%)" : "Tatsächliche Größe (100%)",
    "Fit size" : "Größe anpassen",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Vorschau Ihrer favorisierten Dateien und viel mehr!"
},
"nplurals=2; plural=(n != 1);");
